# 5.4+ enables Perl by default
# IB-20070304 disable embedded perl, 
# to perform further check against other TSL packages
%define netsnmp_embedded_perl 0
%define netsnmp_perl_modules 1

# check for -without_embedded_perl
%{?_without_embedded_perl:%define netsnmp_embedded_perl 0}

# check for -without_perl_modules
%{?_without_perl_modules:%define netsnmp_perl_modules 0}

# if embedded_perl or perl_modules specified, includes some Perl stuff
%if 0%{?netsnmp_embedded_perl} || 0%{?netsnmp_perl_modules}
%define netsnmp_include_perl 1
%endif

# library version (see Makefile.top)
%define libcurrent 15

#
Summary: Tools and servers for the SNMP protocol
Name: net-snmp
Version: 5.4
Release: 2tr
URL: http://net-snmp.sourceforge.net/
Copyright: BSDish
Group: Trustix Official
Source: http://prdownloads.sourceforge.net/net-snmp/net-snmp-%{version}.tar.gz
Source1: snmpd.init
Source2: snmptrapd.init
Source3: snmpd.conf.EXAMPLE
Source4: sysconfig.snmp
Source5: snmpd.conf.base
Source6: snmptrapd.conf.base
##Source7: net-snmp-5.2.1-perlreqexclude.sh
Source8: net-snmp-logrotate
#Patch0: net-snmp-5.2.1-fixproc.patch
Prereq: openssl
BuildRoot: %{_tmppath}/%{name}-root
BuildRequires: perl

%description
Net-SNMP provides tools and libraries relating to the Simple Network
Management Protocol including: An extensible agent, An SNMP library,
tools to request or set information from SNMP agents, tools to
generate and handle SNMP traps, etc.  Using SNMP you can check the
status of a network of computers, routers, switches, servers, ... to
evaluate the state of your network.
If you need a basic secure config for both snmpd and snmptrapd, 
install %{name}-config package.

%if %{netsnmp_embedded_perl}
This package includes embedded Perl support within the agent.
%endif


%package utils
Group: Community Contrib
Summary: Network management utilities using SNMP, from the NET-SNMP project.
Requires: net-snmp = %{version}

%description utils
The net-snmp-utils package contains various utilities for use with the
NET-SNMP network management project.

Install this package if you need utilities for managing your network
using the SNMP protocol. You will also need to install the net-snmp
package.


%package devel
Group: Community Contrib
Summary: The includes and static libraries from the Net-SNMP package.
Requires: %{name} = %{version}

%description devel
The net-snmp-devel package contains headers and libraries which are
useful for building SNMP applications, agents, and sub-agents.

%package perl
Group: Community Contrib
Summary: NET-SNMP perl modules and mib2c tool
Requires: %{name} = %{version}, perl >= 5
BuildRequires: perl >= 5

%description perl
The %{name}-perl package contains the perl bindings to NET-SNMP, 
and %{name} programs which need perl

%package config
Group: Community Contrib
Summary: NET-SNMP basic config files
Requires: %{name} = %{version}

%description config
The %{name}-config contains the bare snmp configs to run net-snmp.
You install this package if you want a basic config for snmpd and snmptrapd.

# Default include header location should be /usr/include/net-snmp
%{expand: %%define _includedir %{_includedir}/%{name}}

%define perlver %(rpm -q perl --queryformat '%%{version}' 2>/dev/null)
%define perlvendorarch /usr/lib/perl5/vendor_perl/%{perlver}/%{_arch}-linux-thread-multi


%prep

%if %{netsnmp_embedded_perl} == 1 && %{netsnmp_perl_modules} == 0
echo "'--with-embedded-perl' requires '--with-perl-modules'"
exit 1
%endif

%setup -q
#%patch0 -p1

# Do this patch with a perl hack...
perl -pi -e "s|'\\\$install_libdir'|'%{_libdir}'|" ltmain.sh

%build
%configure --with-defaults 					\
           --with-sys-contact="Unknown" 			\
	   --with-sys-location="Unknown" 			\
	   --with-logfile="/var/log/snmpd.log"         		\
           --with-mib-modules="host smux disman/event-mib ucd-snmp/diskio ip-mib/ipv4InterfaceTable ip-mib/ipv6InterfaceTable" \
           --with-sysconfdir="/etc/snmp" 			\
	   --enable-shared 					\
           --enable-static 					\
	   --with-perl-modules					\
	   --with-cflags="$RPM_OPT_FLAGS"
#	   %{?netsnmp_embedded_perl: --enable-embedded-perl}	\
#	   %{!?netsnmp_embedded_perl: --disable-embedded-perl}	\

make

pushd perl
# Use just built libs for perl module building, not the system libs.
perl Makefile.PL -NET-SNMP-IN-SOURCE=true PREFIX=$RPM_BUILD_ROOT/usr INSTALLDIRS=vendor
make
popd

%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/snmp
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig
mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d
mkdir -p $RPM_BUILD_ROOT/%{_initdir}
install -m 640 %{SOURCE4} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/snmp
#install -m 640 %{SOURCE3} $RPM_BUILD_ROOT/%{_sysconfdir}/snmp/snmpd.conf.EXAMPLE
install -m 640 %{SOURCE5} $RPM_BUILD_ROOT/%{_sysconfdir}/snmp/snmpd.conf
install -m 640 %{SOURCE6} $RPM_BUILD_ROOT/%{_sysconfdir}/snmp/snmptrapd.conf
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT/%{_initdir}/snmpd
install -m 755 %{SOURCE2} $RPM_BUILD_ROOT/%{_initdir}/snmptrapd
install -m 644 %{SOURCE8} $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/snmp

# there seems to be a bug in --includedir parameter
##%makeinstall includedir=${RPM_BUILD_ROOT}/usr/include/net-snmp


# perl modules
pushd perl
make install_vendor
eval $(perl '-V:installvendorarch')
popd


%pre
# Dynamically add the snmpd user BEFORE installing package
if [ -z "`getent group snmpd`" ]; then
        /usr/sbin/groupadd -g 263 snmpd
fi
if [ -z "`getent passwd snmpd`" ]; then
        /usr/sbin/useradd -d /dev/null -s /no/shell \
        -g snmpd -u 263  snmpd
fi


%post
/sbin/chkconfig --add snmpd
/sbin/restart_maybe snmpd
/sbin/chkconfig --add snmptrapd
/sbin/restart_maybe snmptrapd

%preun
if [ "$1" = "0" ]; then
    /etc/init.d/net-snmpd stop
    /sbin/chkconfig --del snmpd
    /etc/init.d/net-snmptrapd stop
    /sbin/chkconfig --del snmptrapd
fi

%postun

# Dynamically remove the snmpd user AFTER removing package
if [ "$1" = "0" ]; then
	if [ -n "`getent passwd snmpd`" ]; then
                /usr/sbin/userdel snmpd
        fi
	if [ -n "`getent group snmpd`" ]; then
        	/usr/sbin/groupdel snmpd
	fi
fi

%clean
#[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)

%doc AGENT.txt ChangeLog CodingStyle COPYING
%doc EXAMPLE.conf.def FAQ INSTALL NEWS PORTING TODO
%doc README README.agentx README.hpux11 README.krb5
%doc README.snmpv3 README.solaris README.thread README.win32
         
%{_initdir}
%dir %attr(750,snmpd,snmpd) %{_sysconfdir}/snmp
%config(noreplace) %verify(not mtime size md5) %attr(640,snmpd,snmpd) %{_sysconfdir}/sysconfig/snmp
%config(noreplace) %verify(not mtime size md5) %attr(644,root,root) %{_sysconfdir}/logrotate.d/snmp
%dir %{_datadir}/snmp
%dir %{_datadir}/snmp/mibs
%dir %{_datadir}/snmp/snmpconf-data
%{_datadir}/snmp/mibs/*
%{_datadir}/snmp/snmpconf-data/*
%{_sbindir}
%{_mandir}/man5/*
%{_mandir}/man8/*
/usr/lib/*.so*

%files utils
%defattr(-,root,root)
%{_bindir}
%{_mandir}/man1/snmp*


%files devel
%defattr(-,root,root)
%{_includedir}
%{_libdir}/*.a
%{_libdir}/*.la
%{_mandir}/man3/[^A-Z]*

%files perl
%defattr(-,root,root)
%{_bindir}/mib2c
%perlvendorarch/auto/
%perlvendorarch/NetSNMP/
%perlvendorarch/Bundle/
%perlvendorarch/SNMP.pm
%{_datadir}/snmp/*.pl
%dir %{_datadir}/snmp/mib2c-data
%{_datadir}/snmp/mib2c.*.conf
%{_mandir}/man1/mib2c*
%{_mandir}/man3/Net*
%{_mandir}/man3/SNMP*


%files config
%defattr(-,root,root)
%config(noreplace) %attr(640,snmpd,snmpd) %{_sysconfdir}/snmp/*


%changelog
* Wed Apr 25 2007 Nived Gopalan <nived at trustix dot org> 5.4-2tr
- Ported to official repository.

* Sun Mar 04 2007 Ivan Brunello <ibrunello at users dot sourceforge dot net > 5.4-1ib
- new upstream
- new python bindings NOT included (will be evaluated at a later stage)
- added ucd-snmp/diskio and ip-mib/ipv[46]InterfaceTable modules.

* Thu Jul 27 2006 Ivan Brunello <ibrunello at users dot sourceforge dot net > 5.3.1-1ib
- new upstream

* Fri Feb 10 2006 Ivan Brunello <ibrunello at users dot sourceforge dot net> 5.3.0.1-1ib
- new upstream

* Thu Jan 12 2006 Ivan Brunello <ibrunello at users dot sourceforge dot net> 5.3-1ib
- new upstream
- added "-A" parameter to sysconfig/snmpd to retain previous version behaviour
  (logs are not appended by default anymore).
- modified snmptrapd.conf to reflect new behaviour 
  (traps are not accepted by default, accept a restricted set instead).

* Tue Dec 06 2005 Ivan Brunello <ibrunello at users dot sourceforge dot net> 5.2.2-1ib
- new upstream

* Thu Sep 08 2005 Ivan Brunello <ibrunello at users dot sourceforge dot net> 5.2.1.2-3ib
- fixed logrotate inclusion

* Tue Aug 02 2005 Ivan Brunello <ibrunello at users dot sourceforge dot net> 5.2.1.2-2ib
- added basic config in seperate package (bug #963)
- added basic logrotate file
- first TSL 3 backport of perl subpackage
- removed /etc/snmp/snmp.conf.EXAMPLE (dubbed documentation file) 

* Mon Jul 11 2005 Ivan Brunello <ibrunello at users dot sourceforge dot net> 5.2.1.2-1ib
- new minor version which fixes a DoS vulnerability when stream sockets 
  have been configured for use (bug #1038)

* Mon Jun 27 2005 Ivan Brunello <ibrunello at users dot sourceforge dot net> 5.2.1-5ib
- backported TSL3.0 Net-snmp fixproc Insecure Temporary File Creation

* Mon Apr 04 2005 Ivan Brunello <ivan dot brunello at aonetinternational dot it> 5.2.1-4ib
- startup scripts cleanup

* Wed Mar 16 2005 Ivan Brunello <ivan dot brunello at aonetinternational dot it> 5.2.1-3ib
- added sysconfig parameters

* Wed Mar 02 2005 Ivan Brunello <ivan dot brunello at aonetinternational dot it> 5.2.1-2ib
- cleanup in init script
- added logrotate
- created utils subpackage
- run snmpd as non-root

* Tue Feb 22 2005 Olaf Rempel <razzor at kopf minux tisch dot de> 5.2.1-1or
- new upstream

* Wed Apr 21 2004 Olaf Rempel <razzor at kopf minux tisch dot de>
- initial build for TSL2.1
- spec file rewritten (removed old RPM stuff and perl stuff)

* Tue Oct 28 2003 rs <rstory@users.sourceforge.net>
- fix conditional perl build after reading rpm docs

* Sat Oct  4 2003 rs <rstory@users.sourceforge.net> - 5.0.9-4
- fix to build without requiring arguments
- separate embedded perl and perl modules options
- fix fix for init.d script for non-/usr/local installation

* Fri Sep 26 2003 Wes Hardaker <hardaker@users.sourceforge.net>
- fix perl's UseNumeric
- fix init.d script for non-/usr/local installation

* Fri Sep 12 2003 Wes Hardaker <hardaker@users.sourceforge.net>
- fixes for 5.0.9's perl support

* Mon Sep 01 2003 Wes Hardaker <hardaker@users.sourceforge.net>
- added perl support

* Wed Oct 09 2002 Wes Hardaker <hardaker@users.sourceforge.net>
- Incorperated most of Mark Harig's better version of the rpm spec and Makefile

* Wed Oct 09 2002 Wes Hardaker <hardaker@users.sourceforge.net>
- Made it possibly almost usable.

* Mon Apr 22 2002 Robert Story <rstory@users.sourceforge.net>
- created

